#
# Unit Tests
#

import os, sys
if __name__ == '__main__':
    execfile(os.path.join(sys.path[0], 'framework.py'))

from Products.PloneTestCase import PloneTestCase

# CHANGE 'DIYPloneStyle' to your product name in the following lines
from Products.DIYPloneStyle.config import *
from Products.DIYPloneStyle.Extensions.utils import getSkinsFolderNames
PROJECTNAME = 'DIYPloneStyle'

PloneTestCase.installProduct(PROJECTNAME)
PloneTestCase.setupPloneSite(products=[PROJECTNAME])

class testSkinsTool(PloneTestCase.PloneTestCase):

    def afterSetUp(self):
        self.tool = getattr(self.portal, 'portal_skins')

    def testSkinSelectionCreated(self):
        self.failUnless(SKINNAME in self.tool.getSkinSelections())

    def testSkinPaths(self):
        foldernames = getSkinsFolderNames(GLOBALS)
        for selection, layers in self.tool.getSkinPaths():
            for foldername in foldernames:
                if selection == SKINNAME:
                    self.failUnless(foldername in layers)
                else:
                    self.failIf(foldername in layers)

    def testSkinSelection(self):
        if SELECTSKIN:
            self.assertEqual(self.tool.getDefaultSkin(), SKINNAME)

    def testSkinFlexibility(self):
        self.assertEqual(self.tool.getAllowAny(), ALLOWSELECTION)

    def testCookiePersistance(self):
        self.assertEqual(self.tool.getCookiePersistence(), PERSISTENTCOOKIE)

    def testRequestVarName(self):
        if REQUESTVARNAME:
            self.assertEqual(self.tool.getRequestVarname(), REQUESTVARNAME)

class testResourceRegistrations(PloneTestCase.PloneTestCase):

    def afterSetUp(self):
        self.csstool = getattr(self.portal, 'portal_css')
        self.jstool = getattr(self.portal, 'portal_javascripts')

    def testStylesheetsInstalled(self):
        stylesheetids = self.csstool.getResourceIds()
        for css in STYLESHEETS:
            self.failUnless(css['id'] in stylesheetids)

    def testJavascriptsInstalled(self):
        javascriptids = self.jstool.getResourceIds()
        for js in JAVASCRIPTS:
            self.failUnless(js['id'] in javascriptids)

    def testSkinExists(self):
        # not sure what this does and where it comes from  ;-)
        self.failUnless(getattr(self.portal, 'renderAllTheStylesheets'))

class testUninstall(PloneTestCase.PloneTestCase):

    def afterSetUp(self):
        self.qitool = getattr(self.portal, 'portal_quickinstaller')
        self.skinstool = getattr(self.portal, 'portal_skins')
        self.csstool = getattr(self.portal, 'portal_css')
        self.jstool = getattr(self.portal, 'portal_javascripts')
        self.qitool.uninstallProducts(products=[PROJECTNAME])

    def testProductUninstalled(self):
        self.failIf(self.qitool.isProductInstalled(PROJECTNAME))

    def testSkinSelectionDeleted(self):
        # I can't see why this one fails
        self.failIf(SKINNAME in self.skinstool.getSkinSelections())

    def testBaseSkinIsDefaultSkin(self):
        # I can't see why this one fails
        self.assertEqual(self.skinstool.getDefaultSkin(), BASESKIN)

    def testDefaultSkinFlexibility(self):
        self.failIf(self.skinstool.getAllowAny())

    def testDefaultCookiePersistance(self):
        self.failIf(self.skinstool.getCookiePersistence())

    def testDefaultRequestVarName(self):
        self.assertNotEqual(self.skinstool.getRequestVarname(), REQUESTVARNAME)

    def testStylesheetsUninstalled(self):
        stylesheetids = self.csstool.getResourceIds()
        for css in STYLESHEETS:
            self.failIf(css['id'] in stylesheetids)

    def testJavascriptsUninstalled(self):
        javascriptids = self.jstool.getResourceIds()
        for js in JAVASCRIPTS:
            self.failIf(js['id'] in javascriptids)

if __name__ == '__main__':
    framework()
else:
    import unittest
    def test_suite():
        suite = unittest.TestSuite()
        suite.addTest(unittest.makeSuite(testSkinsTool))
        suite.addTest(unittest.makeSuite(testResourceRegistrations))
        suite.addTest(unittest.makeSuite(testUninstall))
        return suite
